==> react_image_annotate_ns_workflow-3.0.4.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React from "react";
import Annotator from "../Annotator";
import editable_data from "../OCRJSON/Editable";
import OCR_blocks from "../OCRJSON/OCR_blocks";
export default (function () {
  var _React$useState = React.useState({
    taskDescription: "Annotate each image according to this _markdown_ specification.",
    regionTagList: ["doctors_name", "doctors_qualification"],
    regionClsList: ["doctors_name", "doctors_qualification"],
    enabledTools: ["select", "create-box", "create-polygon"],
    videoName: "",
    videoTime: "0",
    videoSrc: "http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4",
    images: [{
      src: "https://netscribes-development.s3.ap-south-1.amazonaws.com/sample_images/Prescription_samples/108305-1650045029_2.jpg",
      name: "hot-dogs-1",
      regions: [{
        type: "box",
        x: 0.05425204139724521,
        y: 0.10559630252905851,
        w: 0.10946745562130178,
        h: 0.03328402366863907,
        highlighted: true,
        editingLabels: false,
        color: "#f44336",
        cls: "doctors_name",
        id: "35981860315239755",
        qc_label: true,
        keyframes: "0",
        ocr_value: "Dr. Pradip",
        tags: ["doctors_name"],
        tag_count: 1,
        invalid: true,
        invalid_tag: ["doctors_name"],
        update_user: true
      }]
    }, {
      src: "https://www.bianchi.com/wp-content/uploads/2019/07/YPB17I555K.jpg",
      name: "bianchi-oltre-xr4"
    }],
    allowComments: false
  }),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      annotatorProps = _React$useState2[0],
      changeAnnotatorProps = _React$useState2[1];

  var isImageMode = false;

  var handleSubmit = function handleSubmit() {};

  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Annotator, Object.assign({}, annotatorProps, {
    onExit: function onExit(e) {
      return console.log(e);
    },
    column_key: "",
    enabledTools: isImageMode ? ["create-box", "create-polygon", "zoom", "zoom_tool_minus"] : ["select", "zoom", "pan", "create-point", "create-box", "create-polygon", "show-mask", "undo_anntation", "redo_anntation", "create-a-brush", "eraser", "zoom_tool_minus"],
    invaild_show: false,
    showUpdate: !isImageMode,
    rightMenu: !isImageMode,
    isReadingMode: false,
    isImageMode: isImageMode,
    hideSaveNext: isImageMode,
    hideQuery: isImageMode,
    hideSave: isImageMode,
    hideHeader: isImageMode,
    hideHeaderText: isImageMode,
    hideNext: isImageMode,
    hidePrev: isImageMode,
    hideClone: isImageMode,
    hideSettings: isImageMode,
    hideFullScreen: isImageMode,
    handleSubmit: function handleSubmit(state, ocr) {
      return console.log(state, ocr);
    },
    tilte_key: "image_le",
    deleteAnnotationAllow: false,
    annotation_index: 0,
    isMediaLayout: true,
    blocks: OCR_blocks,
    image_ocr_map: [],
    editable_data: editable_data,
    lazyBrush: [{
      id: "28885889064608783",
      qc_label: false,
      tool: "pen",
      points: [260.0249123922856, 327.7799944228297, 297.0251640586801, 265.7795745775657, 347.0255041484024, 276.7796490662416, 368.02564698608575, 296.7797845001977, 388.0257830219747, 286.7797167832196],
      brushRadius: 5,
      type: "brush",
      popUp: {
        open: false,
        classification: {
          value: "doctors_name",
          label: "doctors_name"
        },
        tags: [{
          value: "doctors_name",
          label: "doctors_name"
        }]
      },
      color: "rgba(244,67,54,0.5)",
      isPopupShow: true,
      isparent: true,
      isLocked: false,
      isHide: false,
      update_user: false,
      tag_count: 1,
      invalid: true,
      invalid_tag: [{
        value: "doctors_name",
        label: "doctors_name"
      }]
    }],
    customize_data: [{
      title: "test_custum",
      mandatory: "non-mandatory",
      input_type: "input",
      description: "",
      default_type: "sku",
      display_label: "test_custum",
      other_default_value: "",
      history_hide: true,
      readonly: true,
      content: "test123"
    }, {
      title: "test_result_data",
      mandatory: "non-mandatory",
      input_type: "dependentDropdown",
      description: "",
      default_type: "test_result_data",
      display_label: "Test Result Data",
      other_default_value: "",
      history_hide: true,
      readonly: true
    }]
  })));
});

==> react_image_annotate_ns_workflow-4.0.0.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React from "react";
import Annotator from "../Annotator";
import editable_data from "../OCRJSON/Editable";
import OCR_blocks from "../OCRJSON/OCR_blocks";
export default (function () {
  var _React$useState = React.useState({
    taskDescription: "Annotate each image according to this _markdown_ specification.",
    regionTagList: ["Bag", "Bangles bracelets", "Bathrobe", "Belt", "Blazer", "Blouse saree", "Boots", "Bra", "Briefs", "Camisole", "Casual shoes", "Coats", "Coords", "Corset", "Dress", "Dungree", "Dupatta", "Earcuff", "Earrings", "Ethnic bottom", "Finger rings", "Flats", "Flip flop", "Footware", "Rest"],
    regionClsList: ["Bag", "Bangles bracelets", "Bathrobe", "Belt", "Blazer", "Blouse saree", "Boots", "Bra", "Briefs", "Camisole", "Casual shoes", "Coats", "Coords", "Corset", "Dress", "Dungree", "Dupatta", "Earcuff", "Earrings", "Ethnic bottom", "Finger rings", "Flats", "Flip flop", "Footware", "Rest"],
    enabledTools: ["select", "create-box", "create-polygon"],
    videoName: "",
    videoTime: "0",
    videoSrc: "http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/BigBuckBunny.mp4",
    images: [{
      src: "https://netscribes-development.s3.ap-south-1.amazonaws.com/sample_images/Prescription_samples/108305-1650045029_2.jpg",
      name: "hot-dogs-1",
      regions: [{
        type: "box",
        x: 0.05425204139724521,
        y: 0.10559630252905851,
        w: 0.10946745562130178,
        h: 0.03328402366863907,
        highlighted: true,
        editingLabels: false,
        color: "#f44336",
        cls: "doctors_name",
        id: "35981860315239755",
        qc_label: true,
        keyframes: "0",
        ocr_value: "Dr. Pradip",
        tags: ["doctors_name"],
        tag_count: 1,
        invalid: true,
        invalid_tag: ["doctors_name"],
        update_user: true
      }]
    }, {
      src: "https://www.bianchi.com/wp-content/uploads/2019/07/YPB17I555K.jpg",
      name: "bianchi-oltre-xr4"
    }],
    allowComments: false
  }),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      annotatorProps = _React$useState2[0],
      changeAnnotatorProps = _React$useState2[1];

  var isImageMode = false;

  var handleSubmit = function handleSubmit() {};

  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Annotator, Object.assign({}, annotatorProps, {
    onExit: function onExit(e) {
      return console.log(e);
    },
    column_key: "",
    enabledTools: isImageMode ? ["create-box", "create-polygon", "zoom", "zoom_tool_minus"] : ["select", "zoom", "pan", "create-point", "create-box", "create-polygon", "show-mask", "undo_anntation", "redo_anntation", "create-a-brush", "eraser", "zoom_tool_minus"],
    invaild_show: false,
    showUpdate: !isImageMode,
    rightMenu: !isImageMode,
    isReadingMode: false,
    isImageMode: isImageMode,
    hideSaveNext: isImageMode,
    hideQuery: isImageMode,
    hideSave: isImageMode,
    hideHeader: isImageMode,
    hideHeaderText: isImageMode,
    hideNext: isImageMode,
    hidePrev: isImageMode,
    hideClone: isImageMode,
    hideSettings: isImageMode,
    hideFullScreen: isImageMode,
    handleSubmit: function handleSubmit(state, ocr) {
      return console.log(state, ocr);
    },
    tilte_key: "image_le",
    deleteAnnotationAllow: false,
    annotation_index: 0,
    isMediaLayout: true,
    blocks: OCR_blocks,
    image_ocr_map: [],
    editable_data: editable_data,
    lazyBrush: [{
      id: "28885889064608783",
      qc_label: false,
      tool: "pen",
      points: [260.0249123922856, 327.7799944228297, 297.0251640586801, 265.7795745775657, 347.0255041484024, 276.7796490662416, 368.02564698608575, 296.7797845001977, 388.0257830219747, 286.7797167832196],
      brushRadius: 5,
      type: "brush",
      popUp: {
        open: false,
        classification: {
          value: "doctors_name",
          label: "doctors_name"
        },
        tags: [{
          value: "doctors_name",
          label: "doctors_name"
        }]
      },
      color: "rgba(244,67,54,0.5)",
      isPopupShow: true,
      isparent: true,
      isLocked: false,
      isHide: false,
      update_user: false,
      tag_count: 1,
      invalid: true,
      invalid_tag: [{
        value: "doctors_name",
        label: "doctors_name"
      }]
    }],
    customize_data: [{
      title: "test_custum",
      mandatory: "non-mandatory",
      input_type: "input",
      description: "",
      default_type: "sku",
      display_label: "test_custum",
      other_default_value: "",
      history_hide: true,
      readonly: true,
      content: "test123"
    }, {
      title: "test_result_data",
      mandatory: "non-mandatory",
      input_type: "dependentDropdown",
      description: "",
      default_type: "test_result_data",
      display_label: "Test Result Data",
      other_default_value: "",
      history_hide: true,
      readonly: true
    }]
  })));
});
